Module api

Module api 

Modules

states

Structs

GainMapBundle
Parsed JXL gain map bundle from a jhgm container box.
Image
ImageRect
ImageRectMut
JxlAnimation
JxlBasicInfo
JxlDecoder
High level API using the typestate pattern to forbid invalid usage.
JxlDecoderInner
Low-level, less-type-safe API.
JxlDecoderLimits
Security limits for the JXL decoder to prevent resource exhaustion attacks.
JxlDecoderOptions
JxlExtraChannel
JxlFrameHeader
JxlImage
A decoded JXL image with interleaved RGBA (or GrayAlpha) u8 pixel data.
JxlImageInfo
Image metadata extracted from the file header, without decoding pixels.
JxlOutputBuffer
JxlPixelFormat
OwnedRawImage
Point
RawImageRect
Immutable view into image data. Holds a borrowed slice + row layout info. Copy because it’s just a &[u8] + dimensions.
RawImageRectMut
Mutable view into image data. Holds a borrowed mutable slice + row layout info.
Rect
ToneMapping
Unstoppable
A Stop implementation that never stops (no cooperative cancellation).

Enums

DataTypeTag
Endianness
Error
ExtraChannel
JxlBitDepth
JxlColorEncoding
JxlColorProfile
JxlColorType
JxlDataFormat
JxlPrimaries
JxlProgressiveMode
JxlSignatureType
JxlTransferFunction
JxlWhitePoint
Orientation
ProcessingResult
This type represents the return value of a function that reads input from a bitstream. The variant Complete indicates that the operation was completed successfully, and its return value is available. The variant NeedsMoreInput indicates that more input is needed, and the function should be called again. This variant comes with a size_hint, representing an estimate of the number of additional bytes needed, and a fallback, representing additional information that might be needed to call the function again (i.e. because it takes a decoder object by value).
RenderingIntent

Traits

ImageDataType
Image data type trait. Implementors must be “bag-of-bits” types with no padding, guaranteed by the bytemuck::Pod bound.
JxlBitstreamInput
JxlCms
JxlCmsTransformer
Stop
Cooperative cancellation check.

Functions

check_signature
Checks if the given buffer starts with a valid JPEG XL signature.
compute_md5
decode
Decode a JXL image from a byte slice to RGBA u8 pixels.
decode_with
Decode a JXL image with custom decoder options.
read_header
Read image metadata without decoding pixels.
read_header_with
Read image metadata with custom security limits.

Type Aliases

Result