pub enum JxlColorEncoding {
RgbColorSpace {
white_point: JxlWhitePoint,
primaries: JxlPrimaries,
transfer_function: JxlTransferFunction,
rendering_intent: RenderingIntent,
},
GrayscaleColorSpace {
white_point: JxlWhitePoint,
transfer_function: JxlTransferFunction,
rendering_intent: RenderingIntent,
},
XYB {
rendering_intent: RenderingIntent,
},
}Variants
RgbColorSpace
Fields

white_point: JxlWhitePoint
primaries: JxlPrimaries
transfer_function: JxlTransferFunction
rendering_intent: RenderingIntentGrayscaleColorSpace
Fields

white_point: JxlWhitePoint
transfer_function: JxlTransferFunction
rendering_intent: RenderingIntentXYB
Fields

rendering_intent: RenderingIntentImplementations
Sourceimpl JxlColorEncoding
impl JxlColorEncoding
pub fn from_internal(internal: &ColorEncoding) -> Result<Self>
pub fn get_color_encoding_description(&self) -> String
pub fn maybe_create_profile(&self) -> Result<Option<Vec<u8>>, Error>
pub fn srgb(grayscale: bool) -> Self
Sourcepub fn linear_srgb(grayscale: bool) -> Self
pub fn linear_srgb(grayscale: bool) -> Self
Creates linear sRGB color encoding (sRGB primaries with linear transfer function). This is the fallback output color space for XYB images when the embedded color profile cannot be output to without a CMS.
Sourcepub fn with_linear_tf(&self) -> Self
pub fn with_linear_tf(&self) -> Self
Returns a copy of this encoding with linear transfer function. For XYB encoding, returns linear sRGB as fallback.