ProcessingResult

Enum ProcessingResult 

pub enum ProcessingResult<T, U> {
    Complete {
        result: T,
    },
    NeedsMoreInput {
        size_hint: usize,
        fallback: U,
    },
}
This type represents the return value of a function that reads input from a bitstream. The variant Complete indicates that the operation was completed successfully, and its return value is available. The variant NeedsMoreInput indicates that more input is needed, and the function should be called again. This variant comes with a size_hint, representing an estimate of the number of additional bytes needed, and a fallback, representing additional information that might be needed to call the function again (i.e. because it takes a decoder object by value).

Variants



Complete

Fields

result: T


NeedsMoreInput

Fields

size_hint: usize
fallback: U