JxlDecoderInner

Struct JxlDecoderInner 

pub struct JxlDecoderInner { /* private fields */ }
Low-level, less-type-safe API.

Implementations

Source

impl JxlDecoderInner

pub fn process( &mut self, input: &mut dyn JxlBitstreamInput, buffers: Option<&mut [JxlOutputBuffer<'_>]>, ) -> Result<ProcessingResult<(), ()>>

Process more of the input file. This function will return when reaching the next decoding stage (i.e. finished decoding file/frame header, or finished decoding a frame). If called when decoding a frame with None for buffers, the frame will still be read, but pixel data will not be produced.

pub fn flush_pixels( &mut self, buffers: &mut [JxlOutputBuffer<'_>], ) -> Result<()>

Draws all the pixels we have data for.

Source

impl JxlDecoderInner

pub fn new(options: JxlDecoderOptions) -> Self

Creates a new decoder with the given options and, optionally, CMS.

pub fn basic_info(&self) -> Option<&JxlBasicInfo>

Obtains the image’s basic information, if available.

pub fn embedded_color_profile(&self) -> Option<&JxlColorProfile>

Retrieves the file’s color profile, if available.

pub fn output_color_profile(&self) -> Option<&JxlColorProfile>

Retrieves the current output color profile, if available.

pub fn set_output_color_profile( &mut self, profile: JxlColorProfile, ) -> Result<()>

Specifies the preferred color profile to be used for outputting data. Same semantics as JxlDecoderSetOutputColorProfile.

pub fn current_pixel_format(&self) -> Option<&JxlPixelFormat>

pub fn set_pixel_format(&mut self, pixel_format: JxlPixelFormat)

pub fn frame_header(&self) -> Option<JxlFrameHeader>

pub fn num_completed_passes(&self) -> Option<usize>

Number of passes we have full data for. Returns the minimum number of passes completed across all groups.

pub fn reset(&mut self)

Fully resets the decoder to its initial state.

This clears all state including pixel_format. For animation loop playback, consider using rewind instead which preserves pixel_format.

After calling this, the caller should provide input from the beginning of the file.

pub fn rewind(&mut self) -> bool

Rewinds for animation loop replay, keeping pixel_format setting.

This resets the decoder but preserves the pixel_format configuration, so the caller doesn’t need to re-set it after rewinding.

After calling this, the caller should provide input from the beginning of the file. Headers will be re-parsed, then frames can be decoded again.

Returns true if pixel_format was preserved, false if none was set.

pub fn has_more_frames(&self) -> bool

pub fn frame_index(&self) -> Option<&FrameIndexBox>

Returns the parsed frame index box, if the file contained one.

pub fn gain_map(&self) -> Option<&GainMapBundle>

Returns a reference to the parsed gain map bundle, if the file contained one.

pub fn take_gain_map(&mut self) -> Option<GainMapBundle>

Takes the parsed gain map bundle, if the file contained one. After calling this, gain_map() will return None.

pub fn exif(&self) -> Option<&[u8]>

Returns the raw EXIF data from the Exif container box, if present.

The 4-byte TIFF header offset prefix has been stripped; this returns the raw EXIF/TIFF bytes starting with the byte-order marker (II or MM). Returns None for bare codestreams or files without an Exif box.

pub fn take_exif(&mut self) -> Option<Vec<u8>>

Takes the EXIF data, leaving None in its place.

pub fn xmp(&self) -> Option<&[u8]>

Returns the raw XMP data from the xml container box, if present.

Returns None for bare codestreams or files without an xml box.

pub fn take_xmp(&mut self) -> Option<Vec<u8>>

Takes the XMP data, leaving None in its place.