JxlImage

Struct JxlImage 

#[non_exhaustive]
pub struct JxlImage { pub width: usize, pub height: usize, pub data: Vec<u8>, pub channels: usize, pub is_grayscale: bool, pub info: JxlBasicInfo, pub output_profile: JxlColorProfile, pub embedded_profile: JxlColorProfile, pub gain_map: Option<GainMapBundle>, pub exif: Option<Vec<u8>>, pub xmp: Option<Vec<u8>>, }
A decoded JXL image with interleaved RGBA (or GrayAlpha) u8 pixel data.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
width: usize

Image width in pixels.

height: usize

Image height in pixels.

data: Vec<u8>

Interleaved pixel data: RGBA or GrayAlpha, row-major, tightly packed. Length = width * height * channels where channels is 4 (RGBA) or 2 (GrayAlpha).

channels: usize

Number of channels per pixel (4 for RGBA, 2 for GrayAlpha).

is_grayscale: bool

True if the source image is grayscale (output is GrayAlpha).

info: JxlBasicInfo

Image metadata from the file header.

output_profile: JxlColorProfile

The color profile of the output pixels.

embedded_profile: JxlColorProfile

The color profile embedded in the file.

gain_map: Option<GainMapBundle>

HDR gain map bundle from a jhgm container box, if present.

exif: Option<Vec<u8>>

Raw EXIF data from the Exif container box (TIFF header offset stripped). None for bare codestreams or files without an Exif box.

xmp: Option<Vec<u8>>

Raw XMP data from the xml container box. None for bare codestreams or files without an xml box.