OwnedRawImage

Struct OwnedRawImage 

pub struct OwnedRawImage { /* private fields */ }

Implementations

Source

impl OwnedRawImage

pub fn new(byte_size: (usize, usize)) -> Result<Self>

pub fn new_uninit(byte_size: (usize, usize)) -> Result<Self>

Allocate an output buffer without zeroing.

Safety contract

The caller must ensure every byte is written before being read. This is appropriate for output buffers that the decoder will fully populate.

pub fn new_zeroed_with_padding( byte_size: (usize, usize), offset: (usize, usize), padding: (usize, usize), ) -> Result<Self>

pub fn get_rect_including_padding_mut( &mut self, rect: Rect, ) -> RawImageRectMut<'_>

pub fn get_rect_including_padding(&self, rect: Rect) -> RawImageRect<'_>

pub fn get_rect_mut(&mut self, rect: Rect) -> RawImageRectMut<'_>

pub fn get_rect(&self, rect: Rect) -> RawImageRect<'_>

pub fn row_mut(&mut self, row: usize) -> &mut [u8]

pub fn row(&self, row: usize) -> &[u8]

pub fn byte_size(&self) -> (usize, usize)

pub fn byte_offset(&self) -> (usize, usize)

pub fn byte_padding(&self) -> (usize, usize)

pub fn try_clone(&self) -> Result<OwnedRawImage>