Modules
Structs
- Gain
MapBundle - Parsed JXL gain map bundle from a
jhgmcontainer box. - Image
- Image
Rect - Image
Rect Mut - JxlAnimation
- JxlBasic
Info - JxlDecoder
- High level API using the typestate pattern to forbid invalid usage.
- JxlDecoder
Inner - Low-level, less-type-safe API.
- JxlDecoder
Limits - Security limits for the JXL decoder to prevent resource exhaustion attacks.
- JxlDecoder
Options - JxlExtra
Channel - JxlFrame
Header - JxlImage
- A decoded JXL image with interleaved RGBA (or GrayAlpha) u8 pixel data.
- JxlImage
Info - Image metadata extracted from the file header, without decoding pixels.
- JxlOutput
Buffer - JxlPixel
Format - Owned
RawImage - Point
- RawImage
Rect - Immutable view into image data. Holds a borrowed slice + row layout info.
Copybecause it’s just a&[u8]+ dimensions. - RawImage
Rect Mut - Mutable view into image data. Holds a borrowed mutable slice + row layout info.
- Rect
- Tone
Mapping - Unstoppable
- A
Stopimplementation that never stops (no cooperative cancellation).
Enums
- Data
Type Tag - Endianness
- Error
- Extra
Channel - JxlBit
Depth - JxlColor
Encoding - JxlColor
Profile - JxlColor
Type - JxlData
Format - JxlPrimaries
- JxlProgressive
Mode - JxlSignature
Type - JxlTransfer
Function - JxlWhite
Point - Orientation
- Processing
Result - This type represents the return value of a function that reads input from a bitstream. The
variant
Completeindicates that the operation was completed successfully, and its return value is available. The variantNeedsMoreInputindicates that more input is needed, and the function should be called again. This variant comes with asize_hint, representing an estimate of the number of additional bytes needed, and afallback, representing additional information that might be needed to call the function again (i.e. because it takes a decoder object by value). - Rendering
Intent
Traits
- Image
Data Type - Image data type trait. Implementors must be “bag-of-bits” types with no padding,
guaranteed by the
bytemuck::Podbound. - JxlBitstream
Input - JxlCms
- JxlCms
Transformer - Stop
- Cooperative cancellation check.
Functions
- check_
signature - Checks if the given buffer starts with a valid JPEG XL signature.
- compute_
md5 - decode
- Decode a JXL image from a byte slice to RGBA u8 pixels.
- decode_
with - Decode a JXL image with custom decoder options.
- read_
header - Read image metadata without decoding pixels.
- read_
header_ with - Read image metadata with custom security limits.